==> igniteui-react-18.5.2-beta.0.tgz: package/esm5/lib/igr-dropdown-item.js <==
import { __extends } from "tslib";
import * as React from 'react';
import { IgrBaseOptionLike } from "./igr-base-option-like";
import { DropdownItem } from "./DropdownItem";
import { IgcDropdownItemComponent, defineComponents } from "igniteui-webcomponents";
/**
 * Represents an item in a dropdown list.
*/
var IgrDropdownItem = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrDropdownItem, _super);
    function IgrDropdownItem(props) {
        var _this = _super.call(this, props) || this;
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcDropdownItemComponent);
        return _this;
    }
    IgrDropdownItem.prototype.createImplementation = function () {
        return new DropdownItem();
    };
    Object.defineProperty(IgrDropdownItem.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrDropdownItem.prototype.componentDidMount = function () {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        _super.prototype.componentDidMount.call(this);
    };
    IgrDropdownItem.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        var div = React.createElement("igc-dropdown-item", {
            ref: this._getMainRef,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    };
    IgrDropdownItem.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    return IgrDropdownItem;
}(IgrBaseOptionLike));
export { IgrDropdownItem };

==> igniteui-react-18.6.1-beta.0.tgz: package/esm5/lib/igr-dropdown-item.js <==
import { __extends } from "tslib";
import * as React from 'react';
import { IgrBaseOptionLike } from "./igr-base-option-like";
import { DropdownItem } from "./DropdownItem";
import { IgcDropdownItemComponent, defineComponents } from "igniteui-webcomponents";
/**
 * Represents an item in a dropdown list.
*/
var IgrDropdownItem = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrDropdownItem, _super);
    function IgrDropdownItem(props) {
        var _this = _super.call(this, props) || this;
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcDropdownItemComponent);
        return _this;
    }
    IgrDropdownItem.prototype.createImplementation = function () {
        return new DropdownItem();
    };
    Object.defineProperty(IgrDropdownItem.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrDropdownItem.prototype.componentDidMount = function () {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        _super.prototype.componentDidMount.call(this);
    };
    IgrDropdownItem.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        var div = React.createElement("igc-dropdown-item", {
            ref: this._getMainRef,
            id: this.props.id,
            class: this.props.className,
            style: style,
            children: children
        });
        return div;
    };
    IgrDropdownItem.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    return IgrDropdownItem;
}(IgrBaseOptionLike));
export { IgrDropdownItem };
